OdooResponse class
Constructors
- OdooResponse(Map result, int statusCode, String newSessionId)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getError(
) → Map -
getErrorMessage(
) → String? -
getResult(
) → dynamic -
getSessionId(
) → String -
getStatusCode(
) → int -
hasError(
) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited