OdooUser class

Constructors

OdooUser()

Properties

companyId int
getter/setter pair
database String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lang String
getter/setter pair
name String
getter/setter pair
partnerId int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String
getter/setter pair
tz String
getter/setter pair
uid int
getter/setter pair
username String
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(OdooResponse response, String sessionId) OdooUser
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited