OdooVersion class

Constructors

OdooVersion()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getMajorVersion() → dynamic
getMicroVersion() int
getMinorVersion() int
getProtocolVersion() int
getReleaseLevel() String
getSerial() int
getServerSerial() String
getVersionInfo() String
isEnterprise() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(OdooResponse response) OdooVersion
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited