OdooConnector class abstract
- Implementers
Constructors
- OdooConnector(String serverURL)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- odooVersion ↔ OdooVersion
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
callRequest(
String url, Map payload) → Future< OdooResponse> -
connect(
) → Future< OdooVersion> -
createPath(
String path) → String -
createPayload(
Map params) → Map -
debugRPC(
bool debug) → void -
getDatabases(
) → Future< List> -
getServerURL(
) → String -
getVersionInfo(
) → Future< OdooVersion> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setSessionId(
String sessionId) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited